@@ -33,6 +33,7 @@ __all__ = (
     "DescribeDBSubnetGroupsPaginatorName",
     "DescribeEventSubscriptionsPaginatorName",
     "DescribeEventsPaginatorName",
+    "DescribeGlobalClustersPaginatorName",
     "DescribeOrderableDBInstanceOptionsPaginatorName",
     "DescribePendingMaintenanceActionsPaginatorName",
     "SourceTypeType",
@@ -52,6 +53,7 @@ DescribeDBInstancesPaginatorName = Literal["describe_db_instances"]
 DescribeDBSubnetGroupsPaginatorName = Literal["describe_db_subnet_groups"]
 DescribeEventSubscriptionsPaginatorName = Literal["describe_event_subscriptions"]
 DescribeEventsPaginatorName = Literal["describe_events"]
+DescribeGlobalClustersPaginatorName = Literal["describe_global_clusters"]
 DescribeOrderableDBInstanceOptionsPaginatorName = Literal["describe_orderable_db_instance_options"]
 DescribePendingMaintenanceActionsPaginatorName = Literal["describe_pending_maintenance_actions"]
 SourceTypeType = Literal[
